@@ -22,164 +22,144 @@ def is_unique(arr):
 
 HUMAN_AMINO_ACIDS = dict(
     A = dict(
-        smile = 'CC(C(=O)O)N',
-        # template_smile = 'NC(C=O)C',
+        smile = 'NC(C=O)C',
         first_atom_idx = 5,
         last_atom_idx = 2,
-        hydroxyl_idx = 4,
-        distogram_atom_idx = 1
+        distogram_atom_idx = 1,
+        token_center_atom_idx = 1,
     ),
     R = dict(
-        smile = 'C(CC(C(=O)O)N)CN=C(N)N',
-        # template_smile = 'NC(C=O)CCCNC(N)=N',
+        smile = 'NC(C=O)CCCNC(N)=N',
         first_atom_idx = 6,
         last_atom_idx = 3,
-        hydroxyl_idx = 5,
-        distogram_atom_idx = 2
+        distogram_atom_idx = 2,
+        token_center_atom_idx = 2,
     ),
     N = dict(
-        smile = 'C(C(C(=O)O)N)C(=O)N',
-        # template_smile = 'NC(C=O)CC(=O)N',
+        smile = 'NC(C=O)CC(=O)N',
         first_atom_idx = 5,
         last_atom_idx = 2,
-        hydroxyl_idx = 4,
-        distogram_atom_idx = 1
+        distogram_atom_idx = 1,
+        token_center_atom_idx = 1,
     ),
     D = dict(
-        smile = 'C(C(C(=O)O)N)C(=O)O',
-        # template_smile = 'NC(C=O)CC(=O)O',
+        smile = 'NC(C=O)CC(=O)O',
         first_atom_idx = 5,
         last_atom_idx = 2,
-        hydroxyl_idx = 8,
-        distogram_atom_idx = 1
+        distogram_atom_idx = 1,
+        token_center_atom_idx = 1,
     ),
     C = dict(
-        smile = 'C(C(C(=O)O)N)S',
-        # template_smile = 'NC(C=O)CS',
+        smile = 'NC(C=O)CS',
         first_atom_idx = 5,
         last_atom_idx = 2,
-        hydroxyl_idx = 4,
-        distogram_atom_idx = 1
+        distogram_atom_idx = 1,
+        token_center_atom_idx = 1,
     ),
     Q = dict(
-        smile = 'C(CC(=O)N)C(C(=O)O)N',
-        # template_smile = 'NC(C=O)CCC(=O)N',
+        smile = 'NC(C=O)CCC(=O)N',
         first_atom_idx = 9,
         last_atom_idx = 6,
-        hydroxyl_idx = 8,
-        distogram_atom_idx = 5
+        distogram_atom_idx = 5,
+        token_center_atom_idx = 5,
     ),
     E = dict(
-        smile = 'C(CC(=O)O)C(C(=O)O)N',
-        # template_smile = 'NC(C=O)CCC(=O)O',
+        smile = 'NC(C=O)CCC(=O)O',
         first_atom_idx = 9,
         last_atom_idx = 6,
-        hydroxyl_idx = 8,
-        distogram_atom_idx = 5
+        distogram_atom_idx = 5,
+        token_center_atom_idx = 5,
     ),
     G = dict(
-        smile = 'C(C(=O)O)N',
-        # template_smile = 'NCC=O',
+        smile = 'NCC=O',
         first_atom_idx = 4,
         last_atom_idx = 1,
-        hydroxyl_idx = 3,
-        distogram_atom_idx = 0
+        distogram_atom_idx = 0,
+        token_center_atom_idx = 0,
     ),
     H = dict(
-        smile = 'C1=C(NC=N1)CC(C(=O)O)N',
-        # template_smile = 'NC(C=O)CC1=CNC=N1',
+        smile = 'NC(C=O)CC1=CNC=N1',
         first_atom_idx = 10,
         last_atom_idx = 7,
-        hydroxyl_idx = 9,
-        distogram_atom_idx = 0
+        distogram_atom_idx = 0,
+        token_center_atom_idx = 0,
     ),
     I = dict(
-        smile = 'CCC(C)C(C(=O)O)N',
-        # template_smile = 'NC(C=O)C(CC)C',
+        smile = 'NC(C=O)C(CC)C',
         first_atom_idx = 8,
         last_atom_idx = 5,
-        hydroxyl_idx = 7,
-        distogram_atom_idx = 0
+        distogram_atom_idx = 0,
+        token_center_atom_idx = 0,
     ),
     L = dict(
-        smile = 'CC(C)CC(C(=O)O)N',
-        # template_smile = 'NC(C=O)CC(C)C',
+        smile = 'NC(C=O)CC(C)C',
         first_atom_idx = 8,
         last_atom_idx = 5,
-        hydroxyl_idx = 7,
-        distogram_atom_idx = 4
+        distogram_atom_idx = 4,
+        token_center_atom_idx = 4,
     ),
     K = dict(
-        smile = 'C(CCN)CC(C(=O)O)N',
-        # template_smile = 'NC(C=O)CCCCN',
+        smile = 'NC(C=O)CCCCN',
         first_atom_idx = 9,
         last_atom_idx = 6,
-        hydroxyl_idx = 8,
-        distogram_atom_idx = 5
+        distogram_atom_idx = 5,
+        token_center_atom_idx = 5,
     ),
     M = dict(
-        smile = 'CSCCC(C(=O)O)N',
-        # template_smile = 'NC(C=O)CCSC',
+        smile = 'NC(C=O)CCSC',
         first_atom_idx = 8,
         last_atom_idx = 5,
-        hydroxyl_idx = 7,
-        distogram_atom_idx = 4
+        distogram_atom_idx = 4,
+        token_center_atom_idx = 4,
     ),
     F = dict(
-        smile = 'C1=CC=C(C=C1)CC(C(=O)O)N',
-        # template_smile = 'NC(C=O)CC1=CC=CC=C1',
+        smile = 'NC(C=O)CC1=CC=CC=C1',
         first_atom_idx = 11,
         last_atom_idx = 8,
-        hydroxyl_idx = 10,
-        distogram_atom_idx = 7
+        distogram_atom_idx = 7,
+        token_center_atom_idx = 7,
     ),
     P = dict(
-        smile = 'C1CC(NC1)C(=O)O',
-        # template_smile = 'N1C(C=O)CCC1',
+        smile = 'N1C(C=O)CCC1',
         first_atom_idx = 3,
         last_atom_idx = 5,
-        hydroxyl_idx = 7,
-        distogram_atom_idx = 2
+        distogram_atom_idx = 2,
+        token_center_atom_idx = 2,
     ),
     S = dict(
-        smile = 'C(C(C(=O)O)N)O',
-        # template_smile = 'NC(C=O)CO',
+        smile = 'NC(C=O)CO',
         first_atom_idx = 5,
         last_atom_idx = 2,
-        hydroxyl_idx = 4,
-        distogram_atom_idx = 1
+        distogram_atom_idx = 1,
+        token_center_atom_idx = 1,
     ),
     T = dict(
-        smile = 'CC(C(C(=O)O)N)O',
-        # template_smile = 'NC(C=O)C(O)C',
+        smile = 'NC(C=O)C(O)C',
         first_atom_idx = 6,
         last_atom_idx = 3,
-        hydroxyl_idx = 5,
-        distogram_atom_idx = 2
+        distogram_atom_idx = 2,
+        token_center_atom_idx = 2,
     ),
     W = dict(
-        smile = 'C1=CC=C2C(=C1)C(=CN2)CC(C(=O)O)N',
-        # template_smile = 'NC(C=O)CC1=CNC2=C1C=CC=C2',
+        smile = 'NC(C=O)CC1=CNC2=C1C=CC=C2',
         first_atom_idx = 14,
         last_atom_idx = 11,
-        hydroxyl_idx = 13,
-        distogram_atom_idx = 10
+        distogram_atom_idx = 10,
+        token_center_atom_idx = 10,
     ),
     Y = dict(
-        smile = 'C1=CC(=CC=C1CC(C(=O)O)N)O',
-        # template_smile = 'NC(C=O)CC1=CC=C(O)C=C1',
+        smile = 'NC(C=O)CC1=CC=C(O)C=C1',
         first_atom_idx = 11,
         last_atom_idx = 8,
-        hydroxyl_idx = 10,
-        distogram_atom_idx = 7
+        distogram_atom_idx = 7,
+        token_center_atom_idx = 7,
     ),
     V = dict(
-        smile = 'CC(C)C(C(=O)O)N',
-        # template_smile = 'NC(C=O)C(C)C',
+        smile = 'NC(C=O)C(C)C',
         first_atom_idx = 7,
         last_atom_idx = 4,
-        hydroxyl_idx = 6,
-        distogram_atom_idx = 3
+        distogram_atom_idx = 3,
+        token_center_atom_idx = 3,
     )
 )
 
@@ -188,79 +168,71 @@ HUMAN_AMINO_ACIDS = dict(
 
 DNA_NUCLEOTIDES = dict(
     A = dict(
-        smile = 'C1C(C(OC1N2C=NC3=C(N=CN=C32)N)COP(=O)(O)O)O',
-        # template_smile = 'OP(=O)(O)OCC1OC(N2C=NC3=C2N=CN=C3N)CC1O',
+        smile = 'OP(=O)(O)OCC1OC(N2C=NC3=C2N=CN=C3N)CC1O',
         complement = 'T',
         first_atom_idx = 20,
         last_atom_idx = 1,
-        hydroxyl_idx = 21,
-        distogram_atom_idx = 4
+        distogram_atom_idx = 4,
+        token_center_atom_idx = 4,
     ),
     C = dict(
-        smile = 'C1C(C(OC1N2C=CC(=NC2=O)N)COP(=O)(O)O)O',
-        # template_smile = 'OP(=O)(O)OCC1OC(N2C(=O)N=C(N)C=C2)CC1O',
+        smile = 'OP(=O)(O)OCC1OC(N2C(=O)N=C(N)C=C2)CC1O',
         complement = 'G',
         first_atom_idx = 17,
         last_atom_idx = 1,
-        hydroxyl_idx = 19,
-        distogram_atom_idx = 4
+        distogram_atom_idx = 4,
+        token_center_atom_idx = 4,
     ),
     G = dict(
-        smile = 'C1C(C(OC1N2C=NC3=C2N=C(NC3=O)N)COP(=O)(O)O)O',
-        # template_smile = 'OP(=O)(O)OCC1OC(N2C=NC3=C2N=C(N)NC3=O)CC1O',
+        smile = 'OP(=O)(O)OCC1OC(N2C=NC3=C2N=C(N)NC3=O)CC1O',
         complement = 'C',
         first_atom_idx = 21,
         last_atom_idx = 1,
-        hydroxyl_idx = 22,
-        distogram_atom_idx = 4
+        distogram_atom_idx = 4,
+        token_center_atom_idx = 4,
     ),
     T = dict(
-        smile = 'CC1=CN(C(=O)NC1=O)C2CC(C(O2)COP(=O)(O)O)O',
-        # template_smile = 'OP(=O)(O)OCC1OC(N2C(=O)NC(=O)C(C)=C2)CC1O',
+        smile = 'OP(=O)(O)OCC1OC(N2C(=O)NC(=O)C(C)=C2)CC1O',
         complement = 'A',
         first_atom_idx = 19,
         last_atom_idx = 11,
-        hydroxyl_idx = 20,
-        distogram_atom_idx = 9
+        distogram_atom_idx = 9,
+        token_center_atom_idx = 8,
     )
 )
 
 RNA_NUCLEOTIDES = dict(
     A = dict(
-        smile = 'C1=NC(=C2C(=N1)N(C=N2)C3C(C(C(O3)COP(=O)(O)O)O)O)N',
-        # template_smile = 'OP(=O)(O)OCC1OC(N2C=NC3=C2N=CN=C3N)C(O)C1O',
+        smile = 'OP(=O)(O)OCC1OC(N2C=NC3=C2N=CN=C3N)C(O)C1O',
         complement = 'U',
         first_atom_idx = 19,
         last_atom_idx = 11,
-        hydroxyl_idx = 20,
-        distogram_atom_idx = 9
+        distogram_atom_idx = 9,
+        token_center_atom_idx = 9,
     ),
     C = dict(
-        smile = 'C1=CN(C(=O)N=C1N)C2C(C(C(O2)COP(=O)([O-])[O-])O)O',
-        # template_smile = 'OP(=O)(O)OCC1OC(N2C(=O)N=C(N)C=C2)C(O)C1O',
+        smile = 'OP(=O)(O)OCC1OC(N2C(=O)N=C(N)C=C2)C(O)C1O',
         complement = 'G',
         first_atom_idx = 17,
         last_atom_idx = 10,
-        hydroxyl_idx = 19,
-        distogram_atom_idx = 8
+        distogram_atom_idx = 8,
+        token_center_atom_idx = 8,
     ),
     G = dict(
-        smile = 'C1=NC2=C(N1C3C(C(C(O3)COP(=O)(O)O)O)O)N=C(NC2=O)N',
-        # template_smile = 'OP(=O)(O)OCC1OC(N2C=NC3=C2N=C(N)NC3=O)C(O)C1O',
+        smile = 'OP(=O)(O)OCC1OC(N2C=NC3=C2N=C(N)NC3=O)C(O)C1O',
         complement = 'C',
         first_atom_idx = 14,
         last_atom_idx = 7,
-        hydroxyl_idx = 16,
-        distogram_atom_idx = 5
+        distogram_atom_idx = 5,
+        token_center_atom_idx = 5,
     ),
     U = dict(
-        smile = 'C1=CN(C(=O)NC1=O)C2C(C(C(O2)COP(=O)(O)O)O)O',
-        # template_smile = 'OP(=O)(O)OCC1OC(N2C(=O)NC(=O)C=C2)C(O)C1O',
+        smile = 'OP(=O)(O)OCC1OC(N2C(=O)NC(=O)C=C2)C(O)C1O',
         complement = 'A',
         first_atom_idx = 18,
         last_atom_idx = 10,
-        hydroxyl_idx = 19,
-        distogram_atom_idx = 8
+        distogram_atom_idx = 8,
+        token_center_atom_idx = 8,
     )
 )
 
@@ -511,23 +483,11 @@ for entry in [*CHAINABLE_BIOMOLECULES, *METALS_AND_MISC]:
     mol = mol_from_smile(entry['smile'])
     entry['rdchem_mol'] = mol
 
-# reorder all the chainable biomolecules
-# to simplify chaining them up and specifying the peptide or phosphodiesterase bonds
-
 for entry in CHAINABLE_BIOMOLECULES:
-    mol = entry['rdchem_mol']
+    num_atoms = mol.GetNumAtoms()
 
-    atom_order = torch.arange(mol.GetNumAtoms())
-
-    atom_order[entry['first_atom_idx']] = -1
-    atom_order[entry['last_atom_idx']] = 1e4
-    atom_order[entry['hydroxyl_idx']] = 1e4 + 1
-
-    atom_reorder = atom_order.argsort()
-
-    mol = Chem.RenumberAtoms(mol, atom_reorder.tolist())
-
-    entry.update(
-        atom_reorder_indices = atom_reorder,
-        rdchem_mol = mol
-    )
+    assert 0 <= entry['distogram_atom_idx'] < num_atoms
+    assert 0 <= entry['first_atom_idx'] < num_atoms
+    assert 0 <= entry['last_atom_idx'] < num_atoms
+    assert entry['first_atom_idx'] != entry['last_atom_idx']
+    assert 0 <= entry['token_center_atom_idx'] < num_atoms
\ No newline at end of file
