@@ -461,7 +461,7 @@ def test_alphafold3(
     msa_mask = torch.ones((2, 7)).bool()
 
     atom_pos = torch.randn(2, atom_seq_len, 3)
-    molecule_atom_indices = molecule_atom_lens - 1
+    distogram_atom_indices = molecule_atom_lens - 1
 
     pae_labels = torch.randint(0, 64, (2, seq_len, seq_len))
     pde_labels = torch.randint(0, 64, (2, seq_len, seq_len))
@@ -511,7 +511,7 @@ def test_alphafold3(
         templates = template_feats,
         template_mask = template_mask,
         atom_pos = atom_pos,
-        molecule_atom_indices = molecule_atom_indices,
+        distogram_atom_indices = distogram_atom_indices,
         pae_labels = pae_labels,
         pde_labels = pde_labels,
         plddt_labels = plddt_labels,
@@ -552,7 +552,7 @@ def test_alphafold3_without_msa_and_templates():
     molecule_ids = torch.randint(0, 32, (2, seq_len))
 
     atom_pos = torch.randn(2, atom_seq_len, 3)
-    molecule_atom_indices = molecule_atom_lens - 1
+    distogram_atom_indices = molecule_atom_lens - 1
 
     distance_labels = torch.randint(0, 38, (2, seq_len, seq_len))
     pae_labels = torch.randint(0, 64, (2, seq_len, seq_len))
@@ -593,7 +593,7 @@ def test_alphafold3_without_msa_and_templates():
         additional_molecule_feats = additional_molecule_feats,
         additional_token_feats = additional_token_feats,
         atom_pos = atom_pos,
-        molecule_atom_indices = molecule_atom_indices,
+        distogram_atom_indices = distogram_atom_indices,
         distance_labels = distance_labels,
         pae_labels = pae_labels,
         pde_labels = pde_labels,
@@ -617,7 +617,7 @@ def test_alphafold3_force_return_loss():
     molecule_ids = torch.randint(0, 32, (2, seq_len))
 
     atom_pos = torch.randn(2, atom_seq_len, 3)
-    molecule_atom_indices = molecule_atom_lens - 1
+    distogram_atom_indices = molecule_atom_lens - 1
 
     distance_labels = torch.randint(0, 38, (2, seq_len, seq_len))
     pae_labels = torch.randint(0, 64, (2, seq_len, seq_len))
@@ -658,7 +658,7 @@ def test_alphafold3_force_return_loss():
         additional_molecule_feats = additional_molecule_feats,
         additional_token_feats = additional_token_feats,
         atom_pos = atom_pos,
-        molecule_atom_indices = molecule_atom_indices,
+        distogram_atom_indices = distogram_atom_indices,
         distance_labels = distance_labels,
         pae_labels = pae_labels,
         pde_labels = pde_labels,
@@ -720,7 +720,7 @@ def test_alphafold3_with_atom_and_bond_embeddings():
     # required for training, but omitted on inference
 
     atom_pos = torch.randn(2, atom_seq_len, 3)
-    molecule_atom_indices = molecule_atom_lens - 1 # last atom, as an example
+    distogram_atom_indices = molecule_atom_lens - 1 # last atom, as an example
 
     distance_labels = torch.randint(0, 37, (2, seq_len, seq_len))
     pae_labels = torch.randint(0, 64, (2, seq_len, seq_len))
@@ -746,7 +746,7 @@ def test_alphafold3_with_atom_and_bond_embeddings():
         templates = template_feats,
         template_mask = template_mask,
         atom_pos = atom_pos,
-        molecule_atom_indices = molecule_atom_indices,
+        distogram_atom_indices = distogram_atom_indices,
         distance_labels = distance_labels,
         pae_labels = pae_labels,
         pde_labels = pde_labels,
